#!/usr/bin/perl
#
# Copyright (c) 2004 Mathieu Roy <yeupou@gnu.org>
# http://yeupou.coleumes.org
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#   USA
#
# $Id: integcheck-shell.pl,v 1.1 2004/01/25 11:24:26 yeupou Exp $
#
# Part of integcheck, http://gna.org/projects/integcheck


use strict;
use Digest::MD5 qw(md5_base64);

our @checklist = ("/bin",
		  "/sbin",
		  "/lib",
		  "/boot",
		  "/etc/cron.d",
		  "/etc/cron.hourly",
		  "/etc/cron.daily",
		  "/etc/cron.weekly",
		  "/etc/cron.monthly",
		  "/etc/init.d",
		  "/etc/rcS.d",
		  "/etc/rc2.d",
		  "/etc/apt",
		  "/etc/inittab",
		  "/etc/profile",
		  "/etc/bash.bashrc",
		  "/etc/modules",
		  "/etc/modules.conf",
		  "/usr/bin", 
		  "/usr/sbin",
		  "/usr/lib",  
		  "/usr/local/bin",
		  "/usr/local/sbin",
		  "/usr/local/lib");

if (-e "/etc/checklist") {
    # We run the file, but from a security point of view, it may be better
    # to have a read-only file parsed.
    # If you want to fix that, go ahead.
    # This file must be writable only by root and executable-readable only
    # for the integcheck user.
    do "/etc/checklist"
	or print "Unable to run /etc/checklist\n";
}

# check for subdirs
# We use find, it is maybe not the faster way to do it,
# if you have something better to propose, go ahead.
foreach my $dir (@checklist) {
    open(FIND, "find $dir -type d -mindepth 1 ! -name \"lost+found\" |");
    while (<FIND>) {
	chomp($_);
	push(@checklist, $_);
    }
    close(FIND);
}


# go
print "#### Start HERE ####\n";
 
foreach my $dir (@checklist) {
    if (-e $dir) {
	print "$dir:".md5_base64("$dir")."\n";
	if (-d $dir) {
	    # if it's a directory, look inside
	    opendir(REP, $dir);
	    while (defined(my $file = readdir(REP))) {
		next if $file =~ /^\.$/;
		next if $file =~ /^\.\.$/;
		next if $file =~ /^lost\+found$/;
		print "$dir/$file:".md5_base64("$dir/$file")."\n";
	    }
	    closedir(REP);
	}
    } else {
	print "$dir not found!\n";
    }
}

print "#### Finish HERE ####\n";

exit;

# EOF
